@@ -25,6 +25,7 @@ from telliot_feeds.feeds.eth_usd_feed import eth_usd_median_feed
 from telliot_feeds.feeds.trb_usd_feed import trb_usd_median_feed
 from telliot_feeds.sources.etherscan_gas import EtherscanGasPriceSource
 from telliot_feeds.utils.log import get_logger
+from telliot_feeds.utils.reporter_utils import has_native_token_funds
 from telliot_feeds.utils.reporter_utils import is_online
 from telliot_feeds.utils.reporter_utils import tellor_suggested_report
 
@@ -51,6 +52,8 @@ class IntervalReporter:
         priority_fee: int = 5,
         legacy_gas_price: Optional[int] = None,
         gas_price_speed: str = "fast",
+        wait_period: int = 10,
+        min_native_token_balance: int = 10**18,
     ) -> None:
 
         self.endpoint = endpoint
@@ -70,6 +73,8 @@ class IntervalReporter:
         self.gas_price_speed = gas_price_speed
         self.trb_usd_median_feed = trb_usd_median_feed
         self.eth_usd_median_feed = eth_usd_median_feed
+        self.wait_period = wait_period
+        self.min_native_token_balance = min_native_token_balance
 
         logger.info(f"Reporting with account: {self.acct_addr}")
 
@@ -289,12 +294,24 @@ class IntervalReporter:
         return self.datafeed
 
     async def get_num_reports_by_id(self, query_id: bytes) -> Tuple[int, ResponseStatus]:
-        count, read_status = await self.oracle.read(func_name="getTimestampCountById", _queryId=query_id)
+        count, read_status = await self.oracle.read(func_name="getNewValueCountbyQueryId", _queryId=query_id)
         return count, read_status
 
     async def is_online(self) -> bool:
         return await is_online()
 
+    def has_native_token(self) -> bool:
+        return has_native_token_funds(self.acct_addr, self.endpoint._web3, min_balance=self.min_native_token_balance)
+
+    def get_acct_nonce(self) -> tuple[Optional[int], ResponseStatus]:
+        """Get transaction count for an address"""
+        try:
+            return self.endpoint._web3.eth.get_transaction_count(self.acct_addr), ResponseStatus()
+        except ValueError as e:
+            return None, error_status("Account nonce request timed out", e=e, log=logger.warning)
+        except Exception as e:
+            return None, error_status("Unable to retrieve account nonce", e=e, log=logger.error)
+
     async def report_once(
         self,
     ) -> Tuple[Optional[AttributeDict[Any, Any]], ResponseStatus]:
@@ -327,8 +344,6 @@ class IntervalReporter:
 
         status = ResponseStatus()
 
-        address = to_checksum_address(self.account.address)
-
         # Update datafeed value
         await datafeed.source.fetch_new_datapoint()
         latest_data = datafeed.source.latest
@@ -342,6 +357,7 @@ class IntervalReporter:
         query_data = query.query_data
         try:
             value = query.value_type.encode(latest_data[0])
+            logger.debug(f"IntervalReporter Encoded value: {value.hex()}")
         except Exception as e:
             msg = f"Error encoding response value {latest_data[0]}"
             return None, error_status(msg, e=e, log=logger.error)
@@ -363,7 +379,9 @@ class IntervalReporter:
             _nonce=report_count,
             _queryData=query_data,
         )
-        acc_nonce = self.endpoint._web3.eth.get_transaction_count(address)
+        acc_nonce, nonce_status = self.get_acct_nonce()
+        if not nonce_status.ok:
+            return None, nonce_status
 
         # Add transaction type 2 (EIP-1559) data
         if self.transaction_type == 2:
@@ -437,14 +455,19 @@ class IntervalReporter:
 
         return tx_receipt, status
 
-    async def report(self) -> None:
-        """Submit latest values to the TellorX oracle every 12 hours."""
+    async def report(self, report_count: Optional[int] = None) -> None:
+        """Submit values to Tellor oracles on an interval."""
 
-        while True:
+        while report_count is None or report_count > 0:
             online = await self.is_online()
             if online:
-                _, _ = await self.report_once()
+                if self.has_native_token():
+                    _, _ = await self.report_once()
             else:
                 logger.warning("Unable to connect to the internet!")
 
-            await asyncio.sleep(7)
+            logger.info(f"Sleeping for {self.wait_period} seconds")
+            await asyncio.sleep(self.wait_period)
+
+            if report_count is not None:
+                report_count -= 1
